@@ -84,7 +84,7 @@ GetReviewResultsForHIT <-
       )
 
       # Validity check response
-      if(class(response) == "try-error") {
+      if (inherits(response, "try-error")) {
         stop("Request failed")
       }
 
