@@ -74,7 +74,7 @@ GetReviewableHITs <-
       )
 
       # Validity check response
-      if(class(response) == "try-error") {
+      if (inherits(response, "try-error")) {
         stop("Request failed")
       }
 
