@@ -130,7 +130,7 @@ function (qual,
 
   # Update Qualification with any other parameters,
   # but only if we've just created it
-  if(class(response) == "try-error") {
+  if (inherits(response, "try-error")) {
     stop("Unable to update qualification")
   } else {
 
